# questionary

[![Build Status](https://travis-ci.com/tmbo/questionary.svg?branch=master)](https://travis-ci.com/tmbo/questionary)
[![Coverage Status](https://coveralls.io/repos/github/tmbo/questionary/badge.svg?branch=master)](https://coveralls.io/github/tmbo/questionary?branch=master)
[![PyPI version](https://badge.fury.io/py/questionary.svg)](https://badge.fury.io/py/questionary)


Python library to build pretty command line user prompts :star: 

## License
Licensed under the MIT License. Copyright 2018 Tom Bocklisch. [Copy of the license](LICENSE).
